#line 1 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/_ADT/adt.cmod"
/* -*- c -*-
|| This file is part of Pike. For copyright information see COPYRIGHT.
|| Pike is distributed under GPL, LGPL and MPL. See the file COPYING
|| for more information.
|| $Id: adt.cmod,v 1.6 2003/09/10 15:19:09 mast Exp $
*/
#include "global.h"

#include "module_support.h"
#include "sequence.h"
#include "circular_list.h"

#line 15 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/_ADT/adt.cmod"
PIKE_MODULE_INIT
{
  ;
  pike_init_Sequence_module();
  pike_init_CircularList_module();
}

PIKE_MODULE_EXIT
{
  pike_exit_Sequence_module();  
  pike_exit_CircularList_module();  
  ;
} 

